Struct sophus_sensor::camera::Camera

source ·
pub struct Camera<S: IsScalar<BATCH>, const DISTORT: usize, const PARAMS: usize, const BATCH: usize, Distort: IsCameraDistortionImpl<S, DISTORT, PARAMS, BATCH>, Proj: IsProjection<S, BATCH>> { /* private fields */ }
A generic camera model

Implementations

source

impl<S: IsScalar<BATCH>, const DISTORT: usize, const PARAMS: usize, const BATCH: usize, Distort: IsCameraDistortionImpl<S, DISTORT, PARAMS, BATCH>, Proj: IsProjection<S, BATCH>> Camera<S, DISTORT, PARAMS, BATCH, Distort, Proj>

source

pub fn new(params: &S::Vector<PARAMS>, image_size: ImageSize) -> Self

Creates a new camera

source

pub fn from_params_and_size(params: &S::Vector<PARAMS>, size: ImageSize) -> Self

Creates a new camera from parameters and image size

source

pub fn image_size(&self) -> ImageSize

Returns the image size

source

pub fn distort( &self, proj_point_in_camera_z1_plane: &S::Vector<2>, ) -> S::Vector<2>

Distortion - maps a point in the camera z=1 plane to a distorted point

source

pub fn undistort(&self, pixel: &S::Vector<2>) -> S::Vector<2>

Undistortion - maps a distorted pixel to a point in the camera z=1 plane

source

pub fn dx_distort_x( &self, proj_point_in_camera_z1_plane: &S::Vector<2>, ) -> S::Matrix<2, 2>

Derivative of the distortion w.r.t. the point in the camera z=1 plane

source

pub fn cam_proj(&self, point_in_camera: &S::Vector<3>) -> S::Vector<2>

Projects a 3D point in the camera frame to a pixel in the image

source

pub fn cam_unproj(&self, point_in_camera: &S::Vector<2>) -> S::Vector<3>

Unprojects a pixel in the image to a 3D point in the camera frame - assuming z=1

source

pub fn cam_unproj_with_z( &self, point_in_camera: &S::Vector<2>, z: S, ) -> S::Vector<3>

Unprojects a pixel in the image to a 3D point in the camera frame

source

pub fn set_params(&mut self, params: &S::Vector<PARAMS>)

Sets the camera parameters

source

pub fn params(&self) -> &S::Vector<PARAMS>

Returns the camera parameters

source

pub fn is_empty(&self) -> bool

Returns true if the camera is empty

source

pub fn params_examples() -> Vec<S::Vector<PARAMS>>

Examples of valid parameters

source

pub fn invalid_params_examples() -> Vec<S::Vector<PARAMS>>

Examples of invalid parameters