Struct sophus_sensor::camera::Camera
source · pub struct Camera<S: IsScalar<BATCH>, const DISTORT: usize, const PARAMS: usize, const BATCH: usize, Distort: IsCameraDistortionImpl<S, DISTORT, PARAMS, BATCH>, Proj: IsProjection<S, BATCH>> { /* private fields */ }Expand description
A generic camera model
Implementations
sourceimpl<S: IsScalar<BATCH>, const DISTORT: usize, const PARAMS: usize, const BATCH: usize, Distort: IsCameraDistortionImpl<S, DISTORT, PARAMS, BATCH>, Proj: IsProjection<S, BATCH>> Camera<S, DISTORT, PARAMS, BATCH, Distort, Proj>
impl<S: IsScalar<BATCH>, const DISTORT: usize, const PARAMS: usize, const BATCH: usize, Distort: IsCameraDistortionImpl<S, DISTORT, PARAMS, BATCH>, Proj: IsProjection<S, BATCH>> Camera<S, DISTORT, PARAMS, BATCH, Distort, Proj>
sourcepub fn from_params_and_size(params: &S::Vector<PARAMS>, size: ImageSize) -> Self
pub fn from_params_and_size(params: &S::Vector<PARAMS>, size: ImageSize) -> Self
Creates a new camera from parameters and image size
sourcepub fn image_size(&self) -> ImageSize
pub fn image_size(&self) -> ImageSize
Returns the image size
sourcepub fn distort(
&self,
proj_point_in_camera_z1_plane: &S::Vector<2>,
) -> S::Vector<2>
pub fn distort( &self, proj_point_in_camera_z1_plane: &S::Vector<2>, ) -> S::Vector<2>
Distortion - maps a point in the camera z=1 plane to a distorted point
sourcepub fn undistort(&self, pixel: &S::Vector<2>) -> S::Vector<2>
pub fn undistort(&self, pixel: &S::Vector<2>) -> S::Vector<2>
Undistortion - maps a distorted pixel to a point in the camera z=1 plane
sourcepub fn dx_distort_x(
&self,
proj_point_in_camera_z1_plane: &S::Vector<2>,
) -> S::Matrix<2, 2>
pub fn dx_distort_x( &self, proj_point_in_camera_z1_plane: &S::Vector<2>, ) -> S::Matrix<2, 2>
Derivative of the distortion w.r.t. the point in the camera z=1 plane
sourcepub fn cam_proj(&self, point_in_camera: &S::Vector<3>) -> S::Vector<2>
pub fn cam_proj(&self, point_in_camera: &S::Vector<3>) -> S::Vector<2>
Projects a 3D point in the camera frame to a pixel in the image
sourcepub fn cam_unproj(&self, point_in_camera: &S::Vector<2>) -> S::Vector<3>
pub fn cam_unproj(&self, point_in_camera: &S::Vector<2>) -> S::Vector<3>
Unprojects a pixel in the image to a 3D point in the camera frame - assuming z=1
sourcepub fn cam_unproj_with_z(
&self,
point_in_camera: &S::Vector<2>,
z: S,
) -> S::Vector<3>
pub fn cam_unproj_with_z( &self, point_in_camera: &S::Vector<2>, z: S, ) -> S::Vector<3>
Unprojects a pixel in the image to a 3D point in the camera frame
sourcepub fn set_params(&mut self, params: &S::Vector<PARAMS>)
pub fn set_params(&mut self, params: &S::Vector<PARAMS>)
Sets the camera parameters
sourcepub fn params_examples() -> Vec<S::Vector<PARAMS>>
pub fn params_examples() -> Vec<S::Vector<PARAMS>>
Examples of valid parameters
sourcepub fn invalid_params_examples() -> Vec<S::Vector<PARAMS>>
pub fn invalid_params_examples() -> Vec<S::Vector<PARAMS>>
Examples of invalid parameters